==> rc-ui-lib-2.0.4.tgz: package/es/lazyload/LazyloadImage.js <==
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
import React, { useState, useEffect } from "react";
import LazyloadImageEvent from "./LazyloadImageEvent";
import LazyLoadImageObserve from "./LazyloadImageObserve";
import { DEFAULT_EVENTS, hasIntersectionObserver, modeType } from "./utils";
const Lazyload = (props) => {
  const [mode, setMode] = useState("observer");
  const _a = props, {
    observer
  } = _a, resetProps = __objRest(_a, [
    "observer"
  ]);
  useEffect(() => {
    const toSetMode = (value) => {
      if (!hasIntersectionObserver && value === modeType.observer) {
        value = modeType.event;
      }
      setMode(value);
    };
    toSetMode(observer ? modeType.observer : modeType.event);
  }, [observer]);
  return /* @__PURE__ */ React.createElement(React.Fragment, null, mode === modeType.event ? /* @__PURE__ */ React.createElement(LazyloadImageEvent, resetProps) : /* @__PURE__ */ React.createElement(LazyLoadImageObserve, resetProps));
};
Lazyload.defaultProps = {
  loading: null,
  observer: true,
  eventOptions: {
    scrollContainer: document.body,
    offset: 0,
    debounce: 300,
    throttle: 0,
    listenEvents: DEFAULT_EVENTS
  }
};
var stdin_default = Lazyload;
export {
  stdin_default as default
};

==> rc-ui-lib-2.1.1.tgz: package/es/lazyload/LazyloadImage.js <==
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
import React, { useState, useEffect } from "react";
import LazyloadImageEvent from "./LazyloadImageEvent";
import LazyLoadImageObserve from "./LazyloadImageObserve";
import { DEFAULT_EVENTS, hasIntersectionObserver, modeType } from "./utils";
const Lazyload = (props) => {
  const [mode, setMode] = useState();
  const _a = props, {
    observer
  } = _a, resetProps = __objRest(_a, [
    "observer"
  ]);
  useEffect(() => {
    const toSetMode = (value) => {
      if (!hasIntersectionObserver && value === modeType.observer) {
        value = modeType.event;
      }
      setMode(value);
    };
    toSetMode(observer ? modeType.observer : modeType.event);
  }, [observer]);
  return /* @__PURE__ */ React.createElement(React.Fragment, null, mode === modeType.event ? /* @__PURE__ */ React.createElement(LazyloadImageEvent, resetProps) : mode === modeType.observer ? /* @__PURE__ */ React.createElement(LazyLoadImageObserve, resetProps) : null);
};
Lazyload.defaultProps = {
  loading: null,
  observer: true,
  eventOptions: {
    scrollContainer: document.body,
    offset: 0,
    debounce: 300,
    throttle: 0,
    listenEvents: DEFAULT_EVENTS
  }
};
var stdin_default = Lazyload;
export {
  stdin_default as default
};
